# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nauth.proto\x1a\x19google/protobuf/any.proto\x1a\x1bgoogle/protobuf/empty.proto\"0\n\x04User\x12\n\n\x02id\x18\x01 \x01(\x04\x12\r\n\x05login\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\"<\n\x0fRegisterRequest\x12\x12\n\nuser_email\x18\x01 \x01(\t\x12\x15\n\ruser_password\x18\x02 \x01(\t\"C\n\x16ROPCAuthorizationGrant\x12\x12\n\nuser_email\x18\x01 \x01(\t\x12\x15\n\ruser_password\x18\x02 \x01(\t\"S\n\x11IssueTokenRequest\x12\'\n\x04ropc\x18\x02 \x01(\x0b\x32\x17.ROPCAuthorizationGrantH\x00\x42\x15\n\x13\x61uthorization_grant\">\n\x12IssueTokenResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x12\n\ntoken_type\x18\x02 \x01(\t\"#\n\x12RevokeTokenRequest\x12\r\n\x05token\x18\x01 \x01(\t\"F\n\x10\x41uthorizeRequest\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\"\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any2\xf0\x01\n\rAuthorization\x12\x34\n\x08Register\x12\x10.RegisterRequest\x1a\x16.google.protobuf.Empty\x12\x35\n\nIssueToken\x12\x12.IssueTokenRequest\x1a\x13.IssueTokenResponse\x12:\n\x0bRevokeToken\x12\x13.RevokeTokenRequest\x1a\x16.google.protobuf.Empty\x12\x36\n\tAuthorize\x12\x11.AuthorizeRequest\x1a\x16.google.protobuf.Emptyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USER._serialized_start=70
  _USER._serialized_end=118
  _REGISTERREQUEST._serialized_start=120
  _REGISTERREQUEST._serialized_end=180
  _ROPCAUTHORIZATIONGRANT._serialized_start=182
  _ROPCAUTHORIZATIONGRANT._serialized_end=249
  _ISSUETOKENREQUEST._serialized_start=251
  _ISSUETOKENREQUEST._serialized_end=334
  _ISSUETOKENRESPONSE._serialized_start=336
  _ISSUETOKENRESPONSE._serialized_end=398
  _REVOKETOKENREQUEST._serialized_start=400
  _REVOKETOKENREQUEST._serialized_end=435
  _AUTHORIZEREQUEST._serialized_start=437
  _AUTHORIZEREQUEST._serialized_end=507
  _AUTHORIZATION._serialized_start=510
  _AUTHORIZATION._serialized_end=750
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import profile_pb2 as profile__pb2


class ProfileStub(object):
    """Plain methods
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetProfile = channel.unary_unary(
                '/Profile/GetProfile',
                request_serializer=profile__pb2.ProfileKey.SerializeToString,
                response_deserializer=profile__pb2.GetProfileResponse.FromString,
                )
        self.DeleteProfile = channel.unary_unary(
                '/Profile/DeleteProfile',
                request_serializer=profile__pb2.ProfileKey.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateEmployeeProfile = channel.unary_unary(
                '/Profile/CreateEmployeeProfile',
                request_serializer=profile__pb2.Employee.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateEmployeeProfile = channel.unary_unary(
                '/Profile/UpdateEmployeeProfile',
                request_serializer=profile__pb2.Employee.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateEmployerProfile = channel.unary_unary(
                '/Profile/CreateEmployerProfile',
                request_serializer=profile__pb2.Employer.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateEmployerProfile = channel.unary_unary(
                '/Profile/UpdateEmployerProfile',
                request_serializer=profile__pb2.Employer.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetPosition = channel.unary_unary(
                '/Profile/GetPosition',
                request_serializer=profile__pb2.PositionKey.SerializeToString,
                response_deserializer=profile__pb2.Position.FromString,
                )
        self.ListEmployerPositions = channel.unary_stream(
                '/Profile/ListEmployerPositions',
                request_serializer=profile__pb2.ProfileKey.SerializeToString,
                response_deserializer=profile__pb2.Position.FromString,
                )
        self.CreatePosition = channel.unary_unary(
                '/Profile/CreatePosition',
                request_serializer=profile__pb2.CreatePositionRequest.SerializeToString,
                response_deserializer=profile__pb2.PositionKey.FromString,
                )
        self.UpdatePosition = channel.unary_unary(
                '/Profile/UpdatePosition',
                request_serializer=profile__pb2.Position.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeletePosition = channel.unary_unary(
                '/Profile/DeletePosition',
                request_serializer=profile__pb2.PositionKey.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class ProfileServicer(object):
    """Plain methods
    """

    def GetProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEmployeeProfile(self, request, context):
        """Employee related methods

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEmployeeProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEmployerProfile(self, request, context):
        """Employer related methods

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEmployerProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPosition(self, request, context):
        """Positions related method

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEmployerPositions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePosition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePosition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePosition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProfileServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProfile,
                    request_deserializer=profile__pb2.ProfileKey.FromString,
                    response_serializer=profile__pb2.GetProfileResponse.SerializeToString,
            ),
            'DeleteProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteProfile,
                    request_deserializer=profile__pb2.ProfileKey.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateEmployeeProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEmployeeProfile,
                    request_deserializer=profile__pb2.Employee.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateEmployeeProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEmployeeProfile,
                    request_deserializer=profile__pb2.Employee.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateEmployerProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEmployerProfile,
                    request_deserializer=profile__pb2.Employer.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateEmployerProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEmployerProfile,
                    request_deserializer=profile__pb2.Employer.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetPosition': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPosition,
                    request_deserializer=profile__pb2.PositionKey.FromString,
                    response_serializer=profile__pb2.Position.SerializeToString,
            ),
            'ListEmployerPositions': grpc.unary_stream_rpc_method_handler(
                    servicer.ListEmployerPositions,
                    request_deserializer=profile__pb2.ProfileKey.FromString,
                    response_serializer=profile__pb2.Position.SerializeToString,
            ),
            'CreatePosition': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePosition,
                    request_deserializer=profile__pb2.CreatePositionRequest.FromString,
                    response_serializer=profile__pb2.PositionKey.SerializeToString,
            ),
            'UpdatePosition': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePosition,
                    request_deserializer=profile__pb2.Position.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeletePosition': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePosition,
                    request_deserializer=profile__pb2.PositionKey.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Profile', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Profile(object):
    """Plain methods
    """

    @staticmethod
    def GetProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Profile/GetProfile',
            profile__pb2.ProfileKey.SerializeToString,
            profile__pb2.GetProfileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Profile/DeleteProfile',
            profile__pb2.ProfileKey.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateEmployeeProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Profile/CreateEmployeeProfile',
            profile__pb2.Employee.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEmployeeProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Profile/UpdateEmployeeProfile',
            profile__pb2.Employee.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateEmployerProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Profile/CreateEmployerProfile',
            profile__pb2.Employer.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEmployerProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Profile/UpdateEmployerProfile',
            profile__pb2.Employer.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Profile/GetPosition',
            profile__pb2.PositionKey.SerializeToString,
            profile__pb2.Position.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEmployerPositions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/Profile/ListEmployerPositions',
            profile__pb2.ProfileKey.SerializeToString,
            profile__pb2.Position.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Profile/CreatePosition',
            profile__pb2.CreatePositionRequest.SerializeToString,
            profile__pb2.PositionKey.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Profile/UpdatePosition',
            profile__pb2.Position.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Profile/DeletePosition',
            profile__pb2.PositionKey.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: profile.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rprofile.proto\x1a\x1bgoogle/protobuf/empty.proto\"\x1d\n\nProfileKey\x12\x0f\n\x07user_id\x18\x01 \x01(\x04\".\n\x10\x45mployeeEditable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"I\n\x08\x45mployee\x12\x18\n\x03key\x18\x01 \x01(\x0b\x32\x0b.ProfileKey\x12#\n\x08\x65\x64itable\x18\x02 \x01(\x0b\x32\x11.EmployeeEditable\".\n\x10\x45mployerEditable\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\"I\n\x08\x45mployer\x12\x18\n\x03key\x18\x01 \x01(\x0b\x32\x0b.ProfileKey\x12#\n\x08\x65\x64itable\x18\x02 \x01(\x0b\x32\x11.EmployerEditable\"\"\n\x0bPositionKey\x12\x13\n\x0bposition_id\x18\x01 \x01(\x04\"0\n\x11PositionsEditable\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"n\n\x08Position\x12\x19\n\x03key\x18\x01 \x01(\x0b\x32\x0c.PositionKey\x12!\n\x0c\x65mployer_key\x18\x02 \x01(\x0b\x32\x0b.ProfileKey\x12$\n\x08\x65\x64itable\x18\x03 \x01(\x0b\x32\x12.PositionsEditable\"`\n\x15\x43reatePositionRequest\x12!\n\x0c\x65mployer_key\x18\x01 \x01(\x0b\x32\x0b.ProfileKey\x12$\n\x08\x65\x64itable\x18\x02 \x01(\x0b\x32\x12.PositionsEditable\"\x89\x01\n\x12GetProfileResponse\x12\x1d\n\x08\x65mployee\x18\x01 \x01(\x0b\x32\t.EmployeeH\x00\x12\x1d\n\x08\x65mployer\x18\x02 \x01(\x0b\x32\t.EmployerH\x00\x12)\n\x07neither\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x42\n\n\x08response2\xdf\x04\n\x07Profile\x12.\n\nGetProfile\x12\x0b.ProfileKey\x1a\x13.GetProfileResponse\x12\x34\n\rDeleteProfile\x12\x0b.ProfileKey\x1a\x16.google.protobuf.Empty\x12:\n\x15\x43reateEmployeeProfile\x12\t.Employee\x1a\x16.google.protobuf.Empty\x12:\n\x15UpdateEmployeeProfile\x12\t.Employee\x1a\x16.google.protobuf.Empty\x12:\n\x15\x43reateEmployerProfile\x12\t.Employer\x1a\x16.google.protobuf.Empty\x12:\n\x15UpdateEmployerProfile\x12\t.Employer\x1a\x16.google.protobuf.Empty\x12&\n\x0bGetPosition\x12\x0c.PositionKey\x1a\t.Position\x12\x31\n\x15ListEmployerPositions\x12\x0b.ProfileKey\x1a\t.Position0\x01\x12\x36\n\x0e\x43reatePosition\x12\x16.CreatePositionRequest\x1a\x0c.PositionKey\x12\x33\n\x0eUpdatePosition\x12\t.Position\x1a\x16.google.protobuf.Empty\x12\x36\n\x0e\x44\x65letePosition\x12\x0c.PositionKey\x1a\x16.google.protobuf.Emptyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'profile_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROFILEKEY._serialized_start=46
  _PROFILEKEY._serialized_end=75
  _EMPLOYEEEDITABLE._serialized_start=77
  _EMPLOYEEEDITABLE._serialized_end=123
  _EMPLOYEE._serialized_start=125
  _EMPLOYEE._serialized_end=198
  _EMPLOYEREDITABLE._serialized_start=200
  _EMPLOYEREDITABLE._serialized_end=246
  _EMPLOYER._serialized_start=248
  _EMPLOYER._serialized_end=321
  _POSITIONKEY._serialized_start=323
  _POSITIONKEY._serialized_end=357
  _POSITIONSEDITABLE._serialized_start=359
  _POSITIONSEDITABLE._serialized_end=407
  _POSITION._serialized_start=409
  _POSITION._serialized_end=519
  _CREATEPOSITIONREQUEST._serialized_start=521
  _CREATEPOSITIONREQUEST._serialized_end=617
  _GETPROFILERESPONSE._serialized_start=620
  _GETPROFILERESPONSE._serialized_end=757
  _PROFILE._serialized_start=760
  _PROFILE._serialized_end=1367
# @@protoc_insertion_point(module_scope)



from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AuthorizeRequest(_message.Message):
    __slots__ = ["body", "method"]
    BODY_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    body: _any_pb2.Any
    method: str
    def __init__(self, method: _Optional[str] = ..., body: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class IssueTokenRequest(_message.Message):
    __slots__ = ["ropc"]
    ROPC_FIELD_NUMBER: _ClassVar[int]
    ropc: ROPCAuthorizationGrant
    def __init__(self, ropc: _Optional[_Union[ROPCAuthorizationGrant, _Mapping]] = ...) -> None: ...

class IssueTokenResponse(_message.Message):
    __slots__ = ["access_token", "token_type"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOKEN_TYPE_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    token_type: str
    def __init__(self, access_token: _Optional[str] = ..., token_type: _Optional[str] = ...) -> None: ...

class ROPCAuthorizationGrant(_message.Message):
    __slots__ = ["user_email", "user_password"]
    USER_EMAIL_FIELD_NUMBER: _ClassVar[int]
    USER_PASSWORD_FIELD_NUMBER: _ClassVar[int]
    user_email: str
    user_password: str
    def __init__(self, user_email: _Optional[str] = ..., user_password: _Optional[str] = ...) -> None: ...

class RegisterRequest(_message.Message):
    __slots__ = ["user_email", "user_password"]
    USER_EMAIL_FIELD_NUMBER: _ClassVar[int]
    USER_PASSWORD_FIELD_NUMBER: _ClassVar[int]
    user_email: str
    user_password: str
    def __init__(self, user_email: _Optional[str] = ..., user_password: _Optional[str] = ...) -> None: ...

class RevokeTokenRequest(_message.Message):
    __slots__ = ["token"]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: str
    def __init__(self, token: _Optional[str] = ...) -> None: ...

class User(_message.Message):
    __slots__ = ["email", "id", "login"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LOGIN_FIELD_NUMBER: _ClassVar[int]
    email: str
    id: int
    login: str
    def __init__(self, id: _Optional[int] = ..., login: _Optional[str] = ..., email: _Optional[str] = ...) -> None: ...



from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreatePositionRequest(_message.Message):
    __slots__ = ["editable", "employer_key"]
    EDITABLE_FIELD_NUMBER: _ClassVar[int]
    EMPLOYER_KEY_FIELD_NUMBER: _ClassVar[int]
    editable: PositionsEditable
    employer_key: ProfileKey
    def __init__(self, employer_key: _Optional[_Union[ProfileKey, _Mapping]] = ..., editable: _Optional[_Union[PositionsEditable, _Mapping]] = ...) -> None: ...

class Employee(_message.Message):
    __slots__ = ["editable", "key"]
    EDITABLE_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    editable: EmployeeEditable
    key: ProfileKey
    def __init__(self, key: _Optional[_Union[ProfileKey, _Mapping]] = ..., editable: _Optional[_Union[EmployeeEditable, _Mapping]] = ...) -> None: ...

class EmployeeEditable(_message.Message):
    __slots__ = ["desc", "name"]
    DESC_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    desc: str
    name: str
    def __init__(self, name: _Optional[str] = ..., desc: _Optional[str] = ...) -> None: ...

class Employer(_message.Message):
    __slots__ = ["editable", "key"]
    EDITABLE_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    editable: EmployerEditable
    key: ProfileKey
    def __init__(self, key: _Optional[_Union[ProfileKey, _Mapping]] = ..., editable: _Optional[_Union[EmployerEditable, _Mapping]] = ...) -> None: ...

class EmployerEditable(_message.Message):
    __slots__ = ["desc", "name"]
    DESC_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    desc: str
    name: str
    def __init__(self, name: _Optional[str] = ..., desc: _Optional[str] = ...) -> None: ...

class GetProfileResponse(_message.Message):
    __slots__ = ["employee", "employer", "neither"]
    EMPLOYEE_FIELD_NUMBER: _ClassVar[int]
    EMPLOYER_FIELD_NUMBER: _ClassVar[int]
    NEITHER_FIELD_NUMBER: _ClassVar[int]
    employee: Employee
    employer: Employer
    neither: _empty_pb2.Empty
    def __init__(self, employee: _Optional[_Union[Employee, _Mapping]] = ..., employer: _Optional[_Union[Employer, _Mapping]] = ..., neither: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ...) -> None: ...

class Position(_message.Message):
    __slots__ = ["editable", "employer_key", "key"]
    EDITABLE_FIELD_NUMBER: _ClassVar[int]
    EMPLOYER_KEY_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    editable: PositionsEditable
    employer_key: ProfileKey
    key: PositionKey
    def __init__(self, key: _Optional[_Union[PositionKey, _Mapping]] = ..., employer_key: _Optional[_Union[ProfileKey, _Mapping]] = ..., editable: _Optional[_Union[PositionsEditable, _Mapping]] = ...) -> None: ...

class PositionKey(_message.Message):
    __slots__ = ["position_id"]
    POSITION_ID_FIELD_NUMBER: _ClassVar[int]
    position_id: int
    def __init__(self, position_id: _Optional[int] = ...) -> None: ...

class PositionsEditable(_message.Message):
    __slots__ = ["desc", "title"]
    DESC_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    desc: str
    title: str
    def __init__(self, title: _Optional[str] = ..., desc: _Optional[str] = ...) -> None: ...

class ProfileKey(_message.Message):
    __slots__ = ["user_id"]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: int
    def __init__(self, user_id: _Optional[int] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import auth_pb2 as auth__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class AuthorizationStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Register = channel.unary_unary(
                '/Authorization/Register',
                request_serializer=auth__pb2.RegisterRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.IssueToken = channel.unary_unary(
                '/Authorization/IssueToken',
                request_serializer=auth__pb2.IssueTokenRequest.SerializeToString,
                response_deserializer=auth__pb2.IssueTokenResponse.FromString,
                )
        self.RevokeToken = channel.unary_unary(
                '/Authorization/RevokeToken',
                request_serializer=auth__pb2.RevokeTokenRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.Authorize = channel.unary_unary(
                '/Authorization/Authorize',
                request_serializer=auth__pb2.AuthorizeRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class AuthorizationServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Register(self, request, context):
        """
        Creates a new user.
        ERRORS:
        ALREADY_EXISTS_ERROR If the email is already occupied.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IssueToken(self, request, context):
        """
        Issues a new JWT token.
        ERRORS:
        PERMISSION_DENIED: If the email-password pair does not correspond to any user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeToken(self, request, context):
        """
        Revokes the token.
        ERRORS:
        PERMISSION_DENIED: If the authorized user is not the owner of the token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Authorize(self, request, context):
        """
        Check if the authorized user is authorized to perform a certain call.
        ERRORS:
        PERMISSION_DENIED: If the user is not authorized to perform this call.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthorizationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Register': grpc.unary_unary_rpc_method_handler(
                    servicer.Register,
                    request_deserializer=auth__pb2.RegisterRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'IssueToken': grpc.unary_unary_rpc_method_handler(
                    servicer.IssueToken,
                    request_deserializer=auth__pb2.IssueTokenRequest.FromString,
                    response_serializer=auth__pb2.IssueTokenResponse.SerializeToString,
            ),
            'RevokeToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeToken,
                    request_deserializer=auth__pb2.RevokeTokenRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'Authorize': grpc.unary_unary_rpc_method_handler(
                    servicer.Authorize,
                    request_deserializer=auth__pb2.AuthorizeRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Authorization', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Authorization(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Register(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Authorization/Register',
            auth__pb2.RegisterRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IssueToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Authorization/IssueToken',
            auth__pb2.IssueTokenRequest.SerializeToString,
            auth__pb2.IssueTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevokeToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Authorization/RevokeToken',
            auth__pb2.RevokeTokenRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Authorize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Authorization/Authorize',
            auth__pb2.AuthorizeRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
